<?php
/**
 * Theme widgets.
 *
 * @package Clean_Corporate
 */

// Load widget base.
require_once get_template_directory() . '/lib/widget-base/class-widget-base.php';

if ( ! function_exists( 'clean_corporate_load_widgets' ) ) :

	/**
	 * Load widgets.
	 *
	 * @since 1.0.0
	 */
	function clean_corporate_load_widgets() {

		// Social widget.
		register_widget( 'Clean_Corporate_Social_Widget' );

		// Featured Page widget.
		register_widget( 'Clean_Corporate_Featured_Page_Widget' );

		// Latest News widget.
		register_widget( 'Clean_Corporate_Latest_News_Widget' );

		// Call To Action widget.
		register_widget( 'Clean_Corporate_Call_To_Action_Widget' );

		// Services widget.
		register_widget( 'Clean_Corporate_Services_Widget' );

		// Testimonial slider widget.
		register_widget( 'Clean_Corporate_Testimonial_Slider_Widget' );

		// Portfolio Carousel widget.
		register_widget( 'Clean_Corporate_Portfolio_Carousel_Widget' );

		// Portfolio widget.
		register_widget( 'Clean_Corporate_Portfolio_Widget' );

		// Recent Posts widget.
		register_widget( 'Clean_Corporate_Recent_Posts_Widget' );

		// Teams widget.
		register_widget( 'Clean_Corporate_Teams_Widget' );

		if ( class_exists( 'WooCommerce' ) ) {

			// Featured Products Carousel widget.
			register_widget( 'Clean_Corporate_Featured_Products_Carousel_Widget' );

			// Products Grid widget.
			register_widget( 'Clean_Corporate_Products_Grid_Widget' );
		}

	}

endif;

add_action( 'widgets_init', 'clean_corporate_load_widgets' );

if ( ! class_exists( 'Clean_Corporate_Social_Widget' ) ) :

	/**
	 * Social widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Social_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_social',
				'description'                 => __( 'Displays social icons.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				);

			if ( false === has_nav_menu( 'social' ) ) {
				$fields['message'] = array(
					'label' => __( 'Social menu is not set. Please create menu and assign it to Social Menu.', 'clean-corporate-pro' ),
					'type'  => 'message',
					'class' => 'widefat',
					);
			}

			parent::__construct( 'clean-corporate-social', __( 'Clean Corporate: Social', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			if ( has_nav_menu( 'social' ) ) {
				wp_nav_menu( array(
					'theme_location' => 'social',
					'container'      => false,
					'depth'          => 1,
					'link_before'    => '<span class="screen-reader-text">',
					'link_after'     => '</span>',
				) );
			}

			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'Clean_Corporate_Featured_Page_Widget' ) ) :

	/**
	 * Featured page widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Featured_Page_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_featured_page',
				'description'                 => __( 'Displays single featured Page or Post.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'use_page_title' => array(
					'label'   => __( 'Use Page/Post Title as Widget Title', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'featured_page' => array(
					'label'            => __( 'Select Page:', 'clean-corporate-pro' ),
					'type'             => 'dropdown-pages',
					'show_option_none' => __( '&mdash; Select &mdash;', 'clean-corporate-pro' ),
					),
				'id_message' => array(
					'label'            => '<strong>' . _x( 'OR', 'Featured Page Widget', 'clean-corporate-pro' ) . '</strong>',
					'type'             => 'message',
					),
				'featured_post' => array(
					'label'             => __( 'Post ID:', 'clean-corporate-pro' ),
					'placeholder'       => __( 'Eg: 1234', 'clean-corporate-pro' ),
					'type'              => 'text',
					'sanitize_callback' => 'clean_corporate_widget_sanitize_post_id',
					),
				'content_type' => array(
					'label'   => __( 'Show Content:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'full',
					'options' => array(
						'excerpt' => __( 'Excerpt', 'clean-corporate-pro' ),
						'full'    => __( 'Full', 'clean-corporate-pro' ),
						),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'clean-corporate-pro' ),
					'description' => __( 'Applies when Excerpt is selected in Content option.', 'clean-corporate-pro' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 40,
					'min'         => 1,
					'max'         => 400,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'options' => clean_corporate_get_image_sizes_options(),
					),
				'featured_image_alignment' => array(
					'label'   => __( 'Image Alignment:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'center',
					'options' => clean_corporate_get_image_alignment_options(),
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-featured-page', __( 'Clean Corporate: Featured Page', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			// ID validation.
			$our_post_object = null;
			$our_id = '';
			if ( absint( $params['featured_post'] ) > 0 ) {
				$our_id = absint( $params['featured_post'] );
			}
			if ( absint( $params['featured_page'] ) > 0 ) {
				$our_id = absint( $params['featured_page'] );
			}
			if ( absint( $our_id ) > 0 ) {
				$raw_object = get_post( $our_id );
				if ( ! in_array( $raw_object->post_type, array( 'attachment', 'nav_menu_item', 'revision' ) ) ) {
					$our_post_object = $raw_object;
				}
			}
			if ( ! $our_post_object ) {
				// No valid object; bail now!
				return;
			}

			echo $args['before_widget'];

			global $post;
			// Setup global post.
			$post = $our_post_object;
			setup_postdata( $post );

			// Override title if checkbox is selected.
			if ( true === $params['use_page_title'] ) {
				$params['title'] = get_the_title( $post );
			}

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			?>
			<div class="featured-page-widget entry-content">
				<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) : ?>
					<?php the_post_thumbnail( esc_attr( $params['featured_image'] ), array( 'class' => 'align' . esc_attr( $params['featured_image_alignment'] ) ) ); ?>
				<?php endif; ?>
				<?php if ( 'excerpt' === $params['content_type'] ) : ?>
					<?php
						$excerpt = clean_corporate_the_excerpt( absint( $params['excerpt_length'] ) );
						echo wp_kses_post( wpautop( $excerpt ) );
						?>
				<?php else : ?>
					<?php the_content(); ?>
				<?php endif; ?>

			</div><!-- .featured-page-widget -->
			<?php
			// Reset.
			wp_reset_postdata();

			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'Clean_Corporate_Latest_News_Widget' ) ) :

	/**
	 * Latest news widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Latest_News_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'                   => 'clean_corporate_widget_latest_news',
				'description'                 => __( 'Displays latest posts in grid.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 3,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 3,
					'options' => clean_corporate_get_numbers_dropdown_options( 1, 4 ),
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'clean-corporate-thumb',
					'options' => clean_corporate_get_image_sizes_options(),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'clean-corporate-pro' ),
					'description' => __( 'in words', 'clean-corporate-pro' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 15,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'more_text' => array(
					'label'   => __( 'More Text:', 'clean-corporate-pro' ),
					'type'    => 'text',
					'default' => __( 'Read more', 'clean-corporate-pro' ),
					),
				'disable_date' => array(
					'label'   => __( 'Disable Date', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_excerpt' => array(
					'label'   => __( 'Disable Excerpt', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_more_text' => array(
					'label'   => __( 'Disable More Text', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-latest-news', __( 'Clean Corporate: Latest News', 'clean-corporate-pro' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = absint( $params['post_category'] );
			}
			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) : ?>

				<?php global $post; ?>

				<div class="latest-news-widget latest-news-col-<?php echo esc_attr( $params['post_column'] ); ?>">

					<div class="inner-wrapper">

						<?php foreach ( $all_posts as $key => $post ) : ?>
							<?php setup_postdata( $post ); ?>

							<div class="latest-news-item">

									<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) : ?>
										<div class="latest-news-thumb">
											<a href="<?php the_permalink(); ?>">
												<?php
												$img_attributes = array( 'class' => 'aligncenter' );
												the_post_thumbnail( esc_attr( $params['featured_image'] ), $img_attributes );
												?>
											</a>
										</div><!-- .latest-news-thumb -->
									<?php endif; ?>
									<div class="latest-news-text-wrap">

										<div class="latest-news-text-content">
											<h3 class="latest-news-title">
												<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
											</h3><!-- .latest-news-title -->

											<?php if ( false === $params['disable_excerpt'] ) :  ?>
												<div class="latest-news-summary">
												<?php
												$summary = clean_corporate_the_excerpt( esc_attr( $params['excerpt_length'] ), $post );
												echo wp_kses_post( wpautop( $summary ) );
												?>
												</div><!-- .latest-news-summary -->
											<?php endif; ?>
										</div><!-- .latest-news-text-content -->

										<?php if ( false === $params['disable_date'] || false === $params['disable_more_text'] ) : ?>
											<div class="latest-news-meta">
												<ul>
													<?php if ( false === $params['disable_date'] ) :  ?>
														<li class="news-date-meta"><span class="latest-news-date"><?php the_time( 'j M Y' ); ?></span></li>
													<?php endif; ?>
													<?php if ( false === $params['disable_more_text'] ) :  ?>
														<li class="news-read-more"><a href="<?php the_permalink(); ?>"><?php echo esc_html( $params['more_text'] ); ?><span class="screen-reader-text">"<?php the_title(); ?>"</span>
														</a></li>
													<?php endif; ?>
												</ul>
											</div><!-- .latest-news-meta -->
										<?php endif; ?>

									</div><!-- .latest-news-text-wrap -->

							</div><!-- .latest-news-item -->

						<?php endforeach; ?>

					</div><!-- .row -->

				</div><!-- .latest-news-widget -->

				<?php wp_reset_postdata(); ?>

			<?php endif; ?>

			<?php echo $args['after_widget'];

		}
	}
endif;


if ( ! class_exists( 'Clean_Corporate_Call_To_Action_Widget' ) ) :

	/**
	 * Call to action widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Call_To_Action_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_call_to_action',
				'description'                 => __( 'Call To Action Widget.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'description' => array(
					'label' => __( 'Description:', 'clean-corporate-pro' ),
					'type'  => 'textarea',
					'class' => 'widefat',
					),
				'primary_button_text' => array(
					'label'   => __( 'Primary Button Text:', 'clean-corporate-pro' ),
					'default' => __( 'Learn more', 'clean-corporate-pro' ),
					'type'    => 'text',
					'class'   => 'widefat',
					),
				'primary_button_url' => array(
					'label' => __( 'Primary Button URL:', 'clean-corporate-pro' ),
					'type'  => 'url',
					'class' => 'widefat',
					),
				'secondary_button_text' => array(
					'label'   => __( 'Secondary Button Text:', 'clean-corporate-pro' ),
					'default' => '',
					'type'    => 'text',
					'class'   => 'widefat',
					),
				'secondary_button_url' => array(
					'label' => __( 'Secondary Button URL:', 'clean-corporate-pro' ),
					'type'  => 'url',
					'class' => 'widefat',
					),
				'background_image' => array(
					'label'   => __( 'Background Image:', 'clean-corporate-pro' ),
					'type'    => 'image',
					'default' => '',
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-call-to-action', __( 'Clean Corporate: Call To Action', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			// Add background image.
			if ( ! empty( $params['background_image'] ) ) {
				$background_style = '';
				$background_style .= ' style="background-image:url(' . esc_url( $params['background_image'] ) . ');" ';
				$args['before_widget'] = implode( $background_style . ' ' . 'class="', explode( 'class="', $args['before_widget'], 2 ) );
			}

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			?>
			<div class="call-to-action-content">
				<?php if ( ! empty( $params['description'] ) ) : ?>
				    <div class="call-to-action-description">
				        <?php echo wp_kses_post( wpautop( $params['description'] ) ); ?>
				    </div><!-- .call-to-action-description -->
				<?php endif; ?>
				<?php if ( ! empty( $params['primary_button_text'] ) || ! empty( $params['secondary_button_text'] ) ) : ?>
					<div class="call-to-action-buttons">
						<?php if ( ! empty( $params['primary_button_text'] ) ) : ?>
							<a href="<?php echo esc_url( $params['primary_button_url'] ); ?>" class="custom-button btn-call-to-action btn-call-to-primary"><?php echo esc_html( $params['primary_button_text'] ); ?></a>
						<?php endif; ?>
						<?php if ( ! empty( $params['secondary_button_text'] ) ) : ?>
							<a href="<?php echo esc_url( $params['secondary_button_url'] ); ?>" class="custom-button btn-call-to-action btn-call-to-secondary"><?php echo esc_html( $params['secondary_button_text'] ); ?></a>
						<?php endif; ?>
					</div><!-- .call-to-action-buttons -->
				<?php endif; ?>
			</div><!-- .call-to-action-content -->
			<?php

			echo $args['after_widget'];

		}
	}
endif;


if ( ! class_exists( 'Clean_Corporate_Services_Widget' ) ) :

	/**
	 * Social widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Services_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_services',
				'description'                 => __( 'Show your services with icon and read more link.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'clean-corporate-pro' ),
					'description' => __( 'in words', 'clean-corporate-pro' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 15,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'disable_excerpt' => array(
					'label'   => __( 'Disable Excerpt', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 3,
					'options' => clean_corporate_get_numbers_dropdown_options( 2, 4 ),
					),
				);

			for( $i = 1; $i <= 8; $i++ ) {
				$fields[ 'block_heading_' . $i ] = array(
					'label' => __( 'Block', 'clean-corporate-pro' ) . ' #' . $i,
					'type'  => 'heading',
					'class' => 'widefat',
					);
				$fields[ 'block_page_' . $i ] = array(
					'label'            => __( 'Select Page:', 'clean-corporate-pro' ),
					'type'             => 'dropdown-pages',
					'show_option_none' => __( '&mdash; Select &mdash;', 'clean-corporate-pro' ),
					);
				$fields[ 'block_icon_' . $i ] = array(
					'label'       => __( 'Icon:', 'clean-corporate-pro' ),
					'description' => __( 'Eg: fa-cogs', 'clean-corporate-pro' ),
					'type'        => 'text',
					'default'     => 'fa-cogs',
					);
			}

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-services', __( 'Clean Corporate: Services', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$service_arr = array();
			for ( $i = 0; $i < 8 ; $i++ ) {
				$block = ( $i + 1 );
				$service_arr[ $i ] = array(
					'page' => $params[ 'block_page_' . $block ],
					'icon' => $params[ 'block_icon_' . $block ],
					);
			}
			$refined_arr = array();
			if ( ! empty( $service_arr ) ) {
				foreach ( $service_arr as $item ) {
					if ( ! empty( $item['page'] ) ) {
						$refined_arr[ $item['page'] ] = $item;
					}
				}
			}


			if ( ! empty( $refined_arr ) ) {
				$this->render_widget_content( $refined_arr, $params );
			}

			echo $args['after_widget'];

		}

		/**
		 * Render services content.
		 *
		 * @since 1.0.0
		 *
		 * @param array $service_arr Services array.
		 * @param array $params      Parameters array.
		 */
		function render_widget_content( $service_arr, $params ) {

			$column = $params['post_column'];

			$page_ids = array_keys( $service_arr );

			$qargs = array(
				'post__in'       => $page_ids,
				'posts_per_page' => count( $page_ids ),
				'post_type'      => 'page',
				'orderby'        => 'post__in',
				'no_found_rows'  => true,
			);

			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) : ?>

				<?php global $post; ?>

				<div class="service-block-list service-col-<?php echo esc_attr( $column ); ?>">
					<div class="inner-wrapper">

						<?php foreach ( $all_posts as $post ) :  ?>
							<?php setup_postdata( $post ); ?>
							<div class="service-block-item">
								<div class="service-block-inner">
									<?php if ( isset( $service_arr[ $post->ID ]['icon'] ) && ! empty( $service_arr[ $post->ID ]['icon'] ) ) : ?>
										<a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>"><i class="<?php echo 'fa ' . esc_attr( $service_arr[ $post->ID ]['icon'] ); ?>"></i></a>
									<?php endif; ?>
									<div class="service-block-inner-content">
										<h3 class="service-item-title">
											<a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>">
												<?php echo get_the_title( $post->ID ); ?>
											</a>
										</h3>
										<?php if ( true !== $params['disable_excerpt'] ) :  ?>
											<div class="service-block-item-excerpt">
												<?php
												$excerpt = clean_corporate_the_excerpt( $params['excerpt_length'], $post );
												echo wp_kses_post( wpautop( $excerpt ) );
												?>
											</div><!-- .service-block-item-excerpt -->
										<?php endif; ?>

									</div><!-- .service-block-inner-content -->
								</div><!-- .service-block-inner -->
							</div><!-- .service-block-item -->
						<?php endforeach; ?>

					</div><!-- .inner-wrapper -->

				</div><!-- .service-block-list -->

				<?php wp_reset_postdata(); ?>

			<?php endif; ?>

			<?php
		}

	}
endif;

if ( ! class_exists( 'Clean_Corporate_Testimonial_Slider_Widget' ) ) :

	/**
	 * Testimonial Slider widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Testimonial_Slider_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'   => 'clean_corporate_widget_testimonial_slider',
				'description' => __( 'Displays Testimonials as a Slider.', 'clean-corporate-pro' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'clean-corporate-pro' ),
					'description' => __( 'in words', 'clean-corporate-pro' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 30,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'background_image' => array(
					'label'   => __( 'Background Image:', 'clean-corporate-pro' ),
					'type'    => 'image',
					'default' => '',
					),
				'enable_background_overlay' => array(
					'label'   => __( 'Enable Background Overlay', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'slider_heading' => array(
					'label'   => __( 'SLIDER OPTIONS', 'clean-corporate-pro' ),
					'type'    => 'heading',
					),
				'transition_delay' => array(
					'label'       => __( 'Transition Delay:', 'clean-corporate-pro' ),
					'description' => __( 'in seconds', 'clean-corporate-pro' ),
					'type'        => 'number',
					'default'     => 3,
					'css'         => 'max-width:50px;',
					'min'         => 1,
					'max'         => 10,
					'adjacent'         => true,
					),
				'enable_autoplay' => array(
					'label'   => __( 'Enable Autoplay', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-testimonial-slider', __( 'Clean Corporate: Testimonial Slider', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			// Add background image.
			if ( ! empty( $params['background_image'] ) ) {
				$background_style = '';
				$background_style .= ' style="background-image:url(' . esc_url( $params['background_image'] ) . ');" ';
				$args['before_widget'] = implode( $background_style . ' ' . 'class="', explode( 'class="', $args['before_widget'], 2 ) );
			}

			// Add overlay class.
			$overlay_class = ( true === $params['enable_background_overlay'] ) ? 'overlay-enabled' : 'overlay-disabled' ;
			$args['before_widget'] = implode( 'class="' . $overlay_class . ' ', explode( 'class="', $args['before_widget'], 2 ) );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$testimonial_posts = $this->get_testimonials( $params );

			if ( ! empty( $testimonial_posts ) ) {
				$this->render_testimonials( $testimonial_posts, $params );
			}

			echo $args['after_widget'];

		}

		/**
		 * Return testimonial posts detail.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return array Posts details.
		 */
		function get_testimonials( $params ) {

			$output = array();

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = absint( $params['post_category'] );
			}

			$all_posts = get_posts( $qargs );

			if ( ! empty( $all_posts ) ) {
				$cnt = 0;
				global $post;
				foreach ( $all_posts as $key => $post ) {

					setup_postdata( $post );

					$item = array();
					$item['title']   = get_the_title( $post->ID );
					$item['excerpt'] = clean_corporate_the_excerpt( absint( $params['excerpt_length'] ), $post );
					$item['image']   = null;
					if ( has_post_thumbnail( $post->ID ) ) {
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'thumbnail' );
						if ( ! empty( $image_detail ) ) {
							$item['image'] = $image_detail;
						}
					}
					$output[ $cnt ] = $item;
					$cnt++;

				}
				wp_reset_postdata();
			}

			return $output;

		}

		/**
		 * Render testimonial slider.
		 *
		 * @since 1.0.0
		 *
		 * @param array $testimonials Testimonials.
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_testimonials( $testimonials, $params ) {

			$timeout = 0;
			if ( true === $params['enable_autoplay'] ) {
				$timeout = 1000 * absint( $params['transition_delay'] );
			}
			?>
			<div class="cycle-slideshow"
				data-cycle-slides="> article"
				data-cycle-auto-height="container"
				data-cycle-timeout="<?php echo absint( $timeout ); ?>"
				>
				<div class="cycle-pager"></div>
				<?php foreach ( $testimonials as $testimonial ) : ?>
					<article>
						<div class="testimonial-wrapper">
							<?php if ( ! empty( $testimonial['image'] ) ) : ?>
								<div class="testimonial-thumb">
								<img src="<?php echo esc_url( $testimonial['image'][0] ); ?>" />
								</div>
							<?php endif; ?>
							<div class="testimonial-content-area">
							<?php if ( ! empty( $testimonial['excerpt'] ) ) : ?>
								<div class="testimonial-excerpt">
									<?php echo wp_kses_post( wpautop( $testimonial['excerpt'] ) ); ?>
								</div><!-- .testimonial-excerpt -->
							<?php endif; ?>
							</div> <!-- .testimonial-content-area -->

							<h4><?php echo esc_html( $testimonial['title'] ); ?></h4>
						</div>
					</article>

				<?php endforeach; ?>

			</div><!-- .cycle-slideshow -->
			<?php

		}

	}
endif;

if ( ! class_exists( 'Clean_Corporate_Portfolio_Carousel_Widget' ) ) :

	/**
	 * Portfolio Carousel widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Portfolio_Carousel_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'   => 'clean_corporate_widget_portfolio_carousel',
				'description' => __( 'Displays portfolios in carousel.', 'clean-corporate-pro' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_display' => array(
					'label'   => __( 'Portfolios in Display:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 3,
					'options' => clean_corporate_get_numbers_dropdown_options( 3, 4 ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Portfolios:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'medium',
					'options' => clean_corporate_get_image_sizes_options( false, array( 'thumbnail', 'medium' ), false ),
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-portfolio-carousel', __( 'Clean Corporate: Portfolio Carousel', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$portfolio_posts = $this->get_portfolios( $params );

			if ( ! empty( $portfolio_posts ) ) {
				$this->render_portfolio( $portfolio_posts, $params );
			}

			echo $args['after_widget'];

		}

		/**
		 * Return portfolios posts detail.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return array Posts details.
		 */
		function get_portfolios( $params ) {

			$output = array();

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				'meta_key'       => '_thumbnail_id',
			);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = absint( $params['post_category'] );
			}

			$all_posts = get_posts( $qargs );
			if ( ! empty( $all_posts ) ) {
				$cnt = 0;
				global $post;
				foreach ( $all_posts as $key => $post ) {

					setup_postdata( $post );

					$item                = array();
					$item['ID']          = $post->ID;
					$item['title']       = get_the_title( $post->ID );
					$item['url']         = get_permalink( $post->ID );
					$item['image']       = null;
					$item['image_large'] = null;
					if ( has_post_thumbnail( $post->ID ) ) {
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), esc_attr( $params['featured_image'] ) );
						if ( ! empty( $image_detail ) ) {
							$item['image'] = $image_detail;
						}
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
						if ( ! empty( $image_detail ) ) {
							$item['image_large'] = $image_detail;
						}
					}

					$output[ $cnt ] = $item;
					$cnt++;

				}
				wp_reset_postdata();
			}

			return $output;

		}

		/**
		 * Render portfolios.
		 *
		 * @since 1.0.0
		 *
		 * @param array $portfolios Posts detail.
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_portfolio( $portfolios, $params ) {

			$carousel_args = array(
				'slidesToShow' => esc_attr( $params['post_display'] ),
				'dots'         => false,
				'prevArrow'    => '<span data-role="none" class="slick-prev" tabindex="0"><i class="fa fa-angle-left" aria-hidden="true"></i></span>',
				'nextArrow'    => '<span data-role="none" class="slick-next" tabindex="0"><i class="fa fa-angle-right" aria-hidden="true"></i></span>',
				'responsive'   => array(
					array(
						'breakpoint' => 481,
						'settings'   => array(
							'slidesToShow' => 2,
							),
						),
					array(
						'breakpoint' => 361,
						'settings'   => array(
							'slidesToShow' => 1,
							),
						),
					),
				);

			$carousel_args_encoded = wp_json_encode( $carousel_args );
			?>
			<div class="clean-corporate-portfolio-carousel" data-slick='<?php echo $carousel_args_encoded; ?>'>

				<?php foreach ( $portfolios as $portfolio ) : ?>
					<article class="portfolio-item">
						<div class="portfolio-item-inner">
							<div class="portfolio-thumb">
								<a href="<?php echo esc_url( $portfolio['url'] ); ?>">
									<img src="<?php echo esc_url( $portfolio['image'][0] ); ?>" alt="" />
								</a>
								<div class="portfolio-icons">
									<ul>
										<li><a href="<?php echo esc_url( $portfolio['image_large'][0] ); ?>" class="popup-link"><i class="fa fa-search"></i></a></li>
										<li><a href="<?php echo esc_url( $portfolio['url'] ); ?>"><i class="fa fa-plus"></i></a></li>
									</ul>
								</div><!-- .portfolio-icons -->
							</div><!-- .portfolio-thumb -->
							<h4><a href="<?php echo esc_url( $portfolio['url'] ); ?>"><?php echo esc_html( $portfolio['title'] ); ?></a></h4>
						</div><!-- .portfolio-item-inner -->
					</article><!-- .portfolio-item -->
				<?php endforeach; ?>

			</div><!-- .portfolio-wrapper -->
			<?php

		}

	}
endif;

if ( ! class_exists( 'Clean_Corporate_Portfolio_Widget' ) ) :

	/**
	 * Portfolio widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Portfolio_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'   => 'clean_corporate_widget_portfolio',
				'description' => __( 'Displays portfolios.', 'clean-corporate-pro' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 5,
					'options' => clean_corporate_get_numbers_dropdown_options( 4, 5 ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Portfolios:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 5,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'medium',
					'options' => clean_corporate_get_image_sizes_options( false, array( 'clean-corporate-thumb', 'medium' ), true ),
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-portfolio', __( 'Clean Corporate: Portfolio', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$portfolio_posts = $this->get_portfolios( $params );

			if ( ! empty( $portfolio_posts ) ) {
				$this->render_portfolio( $portfolio_posts, $params );
			}

			echo $args['after_widget'];

		}

		/**
		 * Return portfolios posts detail.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return array Posts details.
		 */
		function get_portfolios( $params ) {

			$output = array();

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				'meta_key'       => '_thumbnail_id',
			);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = absint( $params['post_category'] );
			}

			$all_posts = get_posts( $qargs );
			if ( ! empty( $all_posts ) ) {
				$cnt = 0;
				global $post;
				foreach ( $all_posts as $key => $post ) {

					setup_postdata( $post );

					$item                = array();
					$item['ID']          = $post->ID;
					$item['title']       = get_the_title( $post->ID );
					$item['url']         = get_permalink( $post->ID );
					$item['image']       = null;
					$item['image_large'] = null;
					if ( has_post_thumbnail( $post->ID ) ) {
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), esc_attr( $params['featured_image'] ) );
						if ( ! empty( $image_detail ) ) {
							$item['image'] = $image_detail;
						}
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
						if ( ! empty( $image_detail ) ) {
							$item['image_large'] = $image_detail;
						}
					}

					$output[ $cnt ] = $item;
					$cnt++;

				}
				wp_reset_postdata();
			}

			return $output;

		}

		/**
		 * Render portfolios.
		 *
		 * @since 1.0.0
		 *
		 * @param array $portfolios Posts detail.
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_portfolio( $portfolios, $params ) {

			?>
			<div class="clean-corporate-portfolio portfolio-grid-<?php echo esc_attr( $params['post_column'] ); ?>">

				<?php foreach ( $portfolios as $portfolio ) : ?>
					<article class="portfolio-item">
						<div class="portfolio-item-inner">
							<div class="portfolio-thumb">
								<a href="<?php echo esc_url( $portfolio['url'] ); ?>">
									<img src="<?php echo esc_url( $portfolio['image'][0] ); ?>" alt="" />
								</a>
								<div class="portfolio-icons">
									<ul>
										<li><a href="<?php echo esc_url( $portfolio['image_large'][0] ); ?>" class="popup-link"><i class="fa fa-search"></i></a></li>
										<li><a href="<?php echo esc_url( $portfolio['url'] ); ?>"><i class="fa fa-plus"></i></a></li>
									</ul>
								</div><!-- .portfolio-icons -->
							</div><!-- .portfolio-thumb -->
							<h4><a href="<?php echo esc_url( $portfolio['url'] ); ?>"><?php echo esc_html( $portfolio['title'] ); ?></a></h4>
						</div><!-- .portfolio-item-inner -->
					</article><!-- .portfolio-item -->
				<?php endforeach; ?>

			</div><!-- .portfolio-wrapper -->
			<?php

		}

	}
endif;

if ( ! class_exists( 'Clean_Corporate_Recent_Posts_Widget' ) ) :

	/**
	 * Recent posts widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Recent_Posts_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_recent_posts',
				'description'                 => __( 'Displays recent posts.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'thumbnail',
					'options' => clean_corporate_get_image_sizes_options( true, array( 'disable', 'thumbnail' ), false ),
					),
				'image_width' => array(
					'label'       => __( 'Image Width:', 'clean-corporate-pro' ),
					'type'        => 'number',
					'description' => __( 'px', 'clean-corporate-pro' ),
					'css'         => 'max-width:60px;',
					'adjacent'    => true,
					'default'     => 90,
					'min'         => 1,
					'max'         => 150,
					),
				'disable_date' => array(
					'label'   => __( 'Disable Date', 'clean-corporate-pro' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);

			parent::__construct( 'clean-corporate-recent-posts', __( 'Clean Corporate: Recent Posts', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = $params['post_category'];
			}
			$all_posts = get_posts( $qargs );

			?>
			<?php if ( ! empty( $all_posts ) ) :  ?>

				<?php global $post; ?>

				<div class="recent-posts-wrapper">

					<?php foreach ( $all_posts as $key => $post ) :  ?>
						<?php setup_postdata( $post ); ?>

						<div class="recent-posts-item">

							<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) :  ?>
								<div class="recent-posts-thumb">
									<a href="<?php the_permalink(); ?>">
										<?php
										$img_attributes = array(
											'class' => 'alignleft',
											'style' => 'max-width:' . esc_attr( $params['image_width'] ). 'px;',
											);
										the_post_thumbnail( esc_attr( $params['featured_image'] ), $img_attributes );
										?>
									</a>
								</div><!-- .recent-posts-thumb -->
							<?php endif ?>
							<div class="recent-posts-text-wrap">
								<h3 class="recent-posts-title">
									<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
								</h3><!-- .recent-posts-title -->

								<?php if ( false === $params['disable_date'] ) :  ?>
									<div class="recent-posts-meta">

										<?php if ( false === $params['disable_date'] ) :  ?>
											<span class="recent-posts-date"><?php the_time( get_option( 'date_format' ) ); ?></span><!-- .recent-posts-date -->
										<?php endif; ?>

									</div><!-- .recent-posts-meta -->
								<?php endif; ?>

							</div><!-- .recent-posts-text-wrap -->

						</div><!-- .recent-posts-item -->

					<?php endforeach; ?>

				</div><!-- .recent-posts-wrapper -->

				<?php wp_reset_postdata(); // Reset. ?>

			<?php endif; ?>

			<?php
			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'Clean_Corporate_Teams_Widget' ) ) :

	/**
	 * Teams widget Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Teams_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_teams',
				'description'                 => __( 'Displays teams.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'clean-corporate-pro' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 3,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 3,
					'options' => clean_corporate_get_numbers_dropdown_options( 1, 4 ),
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 'medium',
					'options' => clean_corporate_get_image_sizes_options( false, array( 'thumbnail', 'medium' ), false ),
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-teams', __( 'Clean Corporate: Teams', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			$team_posts = $this->get_teams( $params );

			if ( ! empty( $team_posts ) ) {
				$this->render_teams( $team_posts, $params );
			}

			echo $args['after_widget'];

		}

		/**
		 * Return teams posts detail.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return array Posts details.
		 */
		function get_teams( $params ) {

			$output = array();

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				'meta_key'       => '_thumbnail_id',
			);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['cat'] = absint( $params['post_category'] );
			}

			$all_posts = get_posts( $qargs );
			if ( ! empty( $all_posts ) ) {
				$cnt = 0;
				global $post;
				foreach ( $all_posts as $key => $post ) {

					setup_postdata( $post );

					$item = array();
					$item['ID']    = $post->ID;
					$item['title'] = get_the_title( $post->ID );
					$item['url']   = get_permalink( $post->ID );
					$item['image'] = null;
					if ( has_post_thumbnail( $post->ID ) ) {
						$image_detail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), esc_attr( $params['featured_image'] ) );
						if ( ! empty( $image_detail ) ) {
							$item['image'] = $image_detail;
						}
					}
					$item['position'] = null;
					$item['address']  = null;
					$item['phone']    = null;
					$item['social']   = array();

					$output[ $cnt ] = $item;
					$cnt++;

				}
				wp_reset_postdata();
			}

			return $output;

		}

		/**
		 * Render teams.
		 *
		 * @since 1.0.0
		 *
		 * @param array $team_posts Team posts.
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_teams( $team_posts, $params ) {
			?>

			<?php if ( ! empty( $team_posts ) ) : ?>

				<div class="teams-widget teams-col-<?php echo esc_attr( $params['post_column'] ); ?>">
					<div class="inner-wrapper">
						<?php foreach ( $team_posts as $key => $team ) : ?>

							<div class="team-item">
							<?php if ( ! empty( $team['image'] ) ) : ?>
								<div class="thumb-summary-wrap">
									<div class="team-thumb">
										<a href="<?php echo esc_url( $team['url'] ); ?>">
											<img src="<?php echo esc_url( $team['image'][0] ) ?>" alt="" />
										</a>
									</div><!-- .team-thumb-->
									<div class="team-text-wrap">
										<h3 class="team-title"><a href="<?php echo esc_url( $team['url'] ); ?>"><?php echo esc_html( $team['title'] ); ?></a>
										<?php if ( ! empty( $team['position'] ) ) : ?>
											<span class="position"><?php echo esc_html( $team['position'] ); ?></span>
										<?php endif; ?>
										</h3>
									</div><!-- .team-text-wrap -->
								</div><!-- .thumb-summary-wrap-->
								<?php if ( ! empty( $team['phone'] ) || ! empty( $team['address'] ) ) : ?>
									<div class="team-meta">
										<?php if ( ! empty( $team['phone'] ) ) : ?>
											<span class="phone"><?php echo esc_html( $team['phone'] ); ?></span>
										<?php endif; ?>
										<?php if ( ! empty( $team['address'] ) ) : ?>
											<span class="address"><?php echo esc_html( $team['address'] ); ?></span>
										<?php endif; ?>
									</div><!-- .team-meta -->
								<?php endif; ?>
								<?php if ( ! empty( $team['social'] ) ) : ?>
									<div class="team-social">
										<ul>
										<?php foreach ( $team['social'] as $k => $v ) : ?>
											<?php if ( 'email' === $k ) : ?>
												<li><a target="_blank" href="mailto:<?php echo esc_attr( $v ); ?>" class="<?php echo esc_attr( $k ); ?>"></a></li>
											<?php else : ?>
												<li><a target="_blank" href="<?php echo esc_url( $v ); ?>" class="<?php echo esc_attr( $k ); ?>"></a></li>
											<?php endif; ?>
										<?php endforeach; ?>
										</ul>
									</div><!-- .team-social -->
								<?php endif; ?>
							<?php endif; ?>

							</div><!-- .team-item -->
						<?php endforeach; ?>

					</div><!-- .inner-wrapper -->
				</div><!-- .teams-widget -->

				<?php wp_reset_postdata(); ?>

			<?php endif; ?>

			<?php

		}

	}
endif;

if ( ! class_exists( 'Clean_Corporate_Featured_Products_Carousel_Widget' ) ) :

	/**
	 * Featured Products Carousel Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Featured_Products_Carousel_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'   => 'clean_corporate_widget_featured_products_carousel',
				'description' => __( 'Displays featured products as carousel.', 'clean-corporate-pro' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_number' => array(
					'label'   => __( 'Number of Products:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 6,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-featured-products-carousel', __( 'Clean Corporate: Featured Products Carousel', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			// Render now.
			$this->render_products( $params );

			echo $args['after_widget'];

		}

		/**
		 * Render products.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_products( $params ) {

			$carousel_args = array(
				'slidesToShow' => 4,
				'dots'         => false,
				'prevArrow'    => '<span data-role="none" class="slick-prev" tabindex="0"><i class="fa fa-angle-left" aria-hidden="true"></i></span>',
				'nextArrow'    => '<span data-role="none" class="slick-next" tabindex="0"><i class="fa fa-angle-right" aria-hidden="true"></i></span>',
				'responsive'   => array(
					array(
						'breakpoint' => 1024,
						'settings'   => array(
							'slidesToShow' => 4,
							),
						),
					array(
						'breakpoint' => 768,
						'settings'   => array(
							'slidesToShow' => 4,
							),
						),
					array(
						'breakpoint' => 660,
						'settings'   => array(
							'slidesToShow' => 3,
							),
						),
					array(
						'breakpoint' => 481,
						'settings'   => array(
							'slidesToShow' => 2,
							),
						),
					array(
						'breakpoint' => 360,
						'settings'   => array(
							'slidesToShow' => 1,
							),
						),
					),
				);

			$carousel_args_encoded = wp_json_encode( $carousel_args );

			$meta_query = WC()->query->get_meta_query();
			$meta_query[] = array(
				'key'   => '_featured',
				'value' => 'yes'
			);
			$query_args = array(
				'post_type'           => 'product',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'posts_per_page'      => esc_attr( $params['post_number'] ),
				'meta_query'          => $meta_query,
				'no_found_rows'       => true,
			);

			global $woocommerce_loop;
			$products = new WP_Query( $query_args );

			if ( $products->have_posts() ) {
				?>
				<div class="clean-corporate-woocommerce">
				<div class="clean-corporate-woocommmerce-wrapper">
				<ul class="products clean-corporate-featured-products-carousel" data-slick='<?php echo $carousel_args_encoded; ?>'>

				<?php while ( $products->have_posts() ) : $products->the_post(); ?>

					<?php wc_get_template_part( 'content', 'product' ); ?>

				<?php endwhile; // end of the loop. ?>
				</ul><!-- .products -->
				</div>
				</div><!-- .woocommerce -->
				<?php
			}
			woocommerce_reset_loop();
			wp_reset_postdata();

		}
	}
endif;


if ( ! class_exists( 'Clean_Corporate_Products_Grid_Widget' ) ) :

	/**
	 * Products Grid Class.
	 *
	 * @since 1.0.0
	 */
	class Clean_Corporate_Products_Grid_Widget extends Clean_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {

			$opts = array(
				'classname'                   => 'clean_corporate_widget_products_grid',
				'description'                 => __( 'Displays products in grid.', 'clean-corporate-pro' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'subtitle' => array(
					'label' => __( 'Subtitle:', 'clean-corporate-pro' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'product_category' => array(
					'label'           => __( 'Select Product Category:', 'clean-corporate-pro' ),
					'type'            => 'dropdown-taxonomies',
					'taxonomy'        => 'product_cat',
					'show_option_all' => __( 'All Product Categories', 'clean-corporate-pro' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Products:', 'clean-corporate-pro' ),
					'type'    => 'number',
					'default' => 6,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'clean-corporate-pro' ),
					'type'    => 'select',
					'default' => 4,
					'options' => clean_corporate_get_numbers_dropdown_options( 3, 4 ),
					),
				);

			$animation_fields = clean_corporate_get_widget_animation_fields();
			$fields = array_merge( $fields, $animation_fields );

			parent::__construct( 'clean-corporate-products-grid', __( 'Clean Corporate: Products Grid', 'clean-corporate-pro' ), $opts, array(), $fields );

		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );
			$args = $this->add_animation( $args, $params );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( ! empty( $params['subtitle'] ) ) {
				echo '<p class="widget-subtitle">' . esc_html( $params['subtitle'] ) . '</p>';
			}

			// Render now.
			$this->render_products( $params );

			echo $args['after_widget'];

		}

		/**
		 * Render products.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters.
		 * @return void
		 */
		function render_products( $params ) {

			$query_args = array(
				'post_type'           => 'product',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'posts_per_page'      => esc_attr( $params['post_number'] ),
				'no_found_rows'       => true,
			);
			if ( absint( $params['product_category'] ) > 0 ) {
				$query_args['tax_query'] = array(
					array(
						'taxonomy' => 'product_cat',
						'field'    => 'term_id',
						'terms'    => absint( $params['product_category'] ),
						),
					);
			}

			global $woocommerce_loop;
			$products = new WP_Query( $query_args );

			if ( $products->have_posts() ) {
				?>
				<div class="clean-corporate-woocommerce clean-corporate-woocommerce-product-grid-<?php echo esc_attr( $params['post_column'] ); ?>">

					<ul class="products">

						<?php while ( $products->have_posts() ) : $products->the_post(); ?>

							<?php wc_get_template_part( 'content', 'product' ); ?>

						<?php endwhile; // End of the loop. ?>

					</ul><!-- .products -->

				</div><!-- .woocommerce -->
				<?php
			}
			woocommerce_reset_loop();
			wp_reset_postdata();

		}
	}
endif;
